@@ -281,7 +281,7 @@
 #' LROC paradigm. The first reader is CAD. The highest rating method was used to convert this to an ROC 
 #' dataset. The original LROC data is \code{datasetCadLroc}. Analyzing this \strong{one-treatment}
 #' data requires methods described in the book, specifically, the function  
-#' \link{StSignificanceTestingSingleFixedFactor} analyzes such datasets.
+#' \code{\link{StSignificanceTestingSingleFixedFactor}} analyzes such datasets.
 #' 
 #' @format A list with 8 elements:
 #' \itemize{
@@ -486,7 +486,7 @@
 #' positives where the lesions were correctly localized, and \code{LLIl}, representing true 
 #' positives where the lesions were incorrectly localized. The first reader is CAD
 #' and the remaining readers are radiologists. The function 
-#' \link{StSignificanceTestingSingleFixedFactor} analyzes such datasets. 
+#' \code{\link{StSignificanceTestingSingleFixedFactor}} analyzes such datasets. 
 #' 
 #' @format A list with 9 elements:
 #' \itemize{
@@ -519,7 +519,7 @@
 #' The first treatment factor \code{modalityID1} can be "F" or "I", which represent two CT reconstruction
 #' algorithms. The second treatment factor \code{modalityID2} can be "20" "40"  "60"  "80", which 
 #' represent the mAs values of the image acquisition. The factors are fully crossed. The function 
-#' \link{StSignificanceTestingCrossedModalities} analyzes such datasets.
+#' \code{\link{StSignificanceTestingCrossedModalities}} analyzes such datasets.
 #' 
 #' @format A list with 9 elements:
 #' \itemize{
@@ -548,7 +548,35 @@
 "datasetCrossedModality"
 #' 
 #' 
-#' Simulated degenerate ROC dataset; for testing purposes
+#'
+#' 
+#' Simulated ROI dataset
+#'
+#' Simulated ROI dataset: assumed are 4 ROIs per case, 5 readers, 50 non-dieased and 40 diseased cases.
+#' 
+#' @format A list with 9 elements:
+#' \itemize{
+#' \item{\code{NL}}{ Ratings array [1:2, 1:5, 1:90, 1:4], of non-lesion localizations, NLs}
+#' \item{\code{LL}}{ Ratings array [1:2, 1:5, 1:40, 1:4], of lesion localizations, LLs}
+#' \item{\code{lesionNum}}{ array [1:40], number of lesions per diseased case, varies between 1 and 4}
+#' \item{\code{lesionID}}{ array [1:40, 1:4], labels of lesions on diseased cases}
+#' \item{\code{lesionWeight}}{ array [1:40, 1:4] weights (or clinical importance) of lesions, set to 1 divided by number of lesions in the case}
+#' \item{\code{dataType}}{ "ROI", the data type}
+#' \item{\code{modalityID1}}{ [1:2] "1" "2", treatment labels}
+#' \item{\code{readerID}}{ [1:5] "1" "2" "3" "4" "5", reader labels}
+#' }
+#'
+#' @keywords datasets
+#'
+#' 
+#' @examples
+#' str(datasetROI)
+#'
+#'
+"datasetROI"
+#'
+#'
+#' Simulated degenerate ROC dataset (for testing purposes)
 #'
 #' A simulated degenerated dataset. A degenerate dataset is defined as one with
 #' no interior operating points on the ROC plot. Such data tend to be observed with expert level 
@@ -576,15 +604,15 @@
 "datasetDegenerate"
 #'
 #' 
-#' Binned dataset suitable for checking \link{FitCorCbm}; seed = 123
+#' Binned dataset suitable for checking \code{\link{FitCorCbm}}; seed = 123
 #'
-#' A binned dataset suitable for analysis by \link{FitCorCbm}. It was generated by
+#' A binned dataset suitable for analysis by \code{\link{FitCorCbm}}. It was generated by
 #'    \link{DfCreateCorCbmDataset} by setting the \code{seed} variable to 123. Note
 #'    the formatting of the data as a single treatment two reader dataset, even though
-#'    the actual pairing might be different, see \link{FitCorCbm}. The dataset is 
+#'    the actual pairing might be different, see \code{\link{FitCorCbm}}. The dataset is 
 #'    intentionally large so as to demonstrate the asymptotic convergence of ML estimates, 
-#'    produced by \link{FitCorCbm}, to the population values. The data was generated
-#'    by the following argument values to \link{DfCreateCorCbmDataset}: seed = 123, 
+#'    produced by \code{\link{FitCorCbm}}, to the population values. The data was generated
+#'    by the following argument values to \code{\link{DfCreateCorCbmDataset}}: seed = 123, 
 #'    K1 = 5000, K2 = 5000, desiredNumBins = 5, muX = 1.5, muY = 3, alphaX = 0.4, 
 #'    alphaY = 0.7, rhoNor = 0.3, rhoAbn2 = 0.8. 
 #' 
@@ -607,16 +635,16 @@
 #'    ROC datasets. Medical Physics. 44(6):2207--2222.
 
 #' @examples
-#' str(binnedData123)
+#' str(datasetBinned123)
 #'
-"binnedData123"
+"datasetBinned123"
 #'
 #'
-#' Binned dataset suitable for checking \link{FitCorCbm}; seed = 124
+#' Binned dataset suitable for checking \code{\link{FitCorCbm}}; seed = 124
 #'
-#' A binned dataset suitable for analysis by \link{FitCorCbm}. It was generated by
-#'    \link{DfCreateCorCbmDataset} by setting the \code{seed} variable to 124. 
-#'    Otherwise similar to \link{binnedData123}. 
+#' A binned dataset suitable for analysis by \code{\link{FitCorCbm}}. It was generated by
+#'    \code{\link{DfCreateCorCbmDataset}} by setting the \code{seed} variable to 124. 
+#'    Otherwise similar to \code{\link{datasetBinned123}}. 
 #' 
 #' @format A list with 8 elements:
 #' \itemize{
@@ -637,16 +665,16 @@
 #'    ROC datasets. Medical Physics. 44(6):2207--2222.
 
 #' @examples
-#' str(binnedData124)
+#' str(datasetBinned124)
 #'
-"binnedData124"
+"datasetBinned124"
 #'
 #' 
-#' Binned dataset suitable for checking \link{FitCorCbm}; seed = 125
+#' Binned dataset suitable for checking \code{\link{FitCorCbm}}; seed = 125
 #'
-#' A binned dataset suitable for analysis by \link{FitCorCbm}. It was generated by
-#'    \link{DfCreateCorCbmDataset} by setting the \code{seed} variable to 125. 
-#'    Otherwise similar to \link{binnedData123}. 
+#' A binned dataset suitable for analysis by \code{\link{FitCorCbm}}. It was generated by
+#'    \code{\link{DfCreateCorCbmDataset}} by setting the \code{seed} variable to 125. 
+#'    Otherwise similar to \code{\link{datasetBinned123}}. 
 #' 
 #' @format A list with 8 elements:
 #' \itemize{
@@ -667,9 +695,9 @@
 #'    ROC datasets. Medical Physics. 44(6):2207--2222.
 
 #' @examples
-#' str(binnedData125)
+#' str(datasetBinned125)
 #'
-"binnedData125"
+"datasetBinned125"
 #'
 #'
 
